==> qtjambi-xml-debuginfo-linux-x64-5.15.23.jar: sources/QtJambiXml/QDomEntityReference_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomEntityReference(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomEntityReference")
    QDomEntityReference *_ptr = reinterpret_cast<QDomEntityReference *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomEntityReference()
void __qt_construct_QDomEntityReference(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntityReference()")
    Q_UNUSED(__java_arguments)
    QDomEntityReference *__qt_this = new(__qtjambi_ptr) QDomEntityReference();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomEntityReference::QDomEntityReference()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntityReference_initialize_1native__Lio_qt_xml_QDomEntityReference_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntityReference::QDomEntityReference()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntityReference, sizeof(QDomEntityReference), typeid(QDomEntityReference), 0, false, &deleter_QDomEntityReference, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomEntityReference(QDomEntityReference)
void __qt_construct_QDomEntityReference_cref_QDomEntityReference(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntityReference(QDomEntityReference)")
    jobject x0 = __java_arguments[0].l;
    const QDomEntityReference& __qt_x0 = qtjambi_cast<const QDomEntityReference&>(__jni_env, x0);
    QDomEntityReference *__qt_this = new(__qtjambi_ptr) QDomEntityReference(__qt_x0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomEntityReference::QDomEntityReference(QDomEntityReference)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntityReference_initialize_1native__Lio_qt_xml_QDomEntityReference_2Lio_qt_xml_QDomEntityReference_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject x0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntityReference::QDomEntityReference(QDomEntityReference)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = x0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntityReference_cref_QDomEntityReference, sizeof(QDomEntityReference), typeid(QDomEntityReference), 0, false, &deleter_QDomEntityReference, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomEntityReference
void __qt_destruct_QDomEntityReference(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomEntityReference")
    reinterpret_cast<QDomEntityReference*>(ptr)->~QDomEntityReference();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomEntityReference::operator=(QDomEntityReference)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntityReference_assign_1native_1cref_1QDomEntityReference__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID arg__1)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomEntityReference *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntityReference>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntityReference::operator=(QDomEntityReference)", __this_nativeId)
        const QDomEntityReference& __qt_arg__1 = QtJambiAPI::valueReferenceFromNativeId<QDomEntityReference>(arg__1);
        (*__qt_this) = __qt_arg__1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomEntityReference_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomEntityReference *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntityReference>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomEntityReference(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomEntityReference>("QDomEntityReference", "io/qt/xml/QDomEntityReference");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomEntityReference, {
        ConstructorInfo(&__qt_construct_QDomEntityReference, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomEntityReference_cref_QDomEntityReference, "Lio/qt/xml/QDomEntityReference;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomEntityReference);
    registerMetaType<QDomEntityReference>("QDomEntityReference");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-linux-x64-6.8.3.jar: sources/QtJambiXml/QDomEntityReference_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>
#include <QtCore/qtextstream.h>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomEntityReference(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomEntityReference")
    QDomEntityReference *_ptr = reinterpret_cast<QDomEntityReference *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QDomEntityReference()
void __qt_construct_QDomEntityReference(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntityReference()")
    Q_UNUSED(__java_arguments)
    QDomEntityReference *__qt_this = new(__qtjambi_ptr) QDomEntityReference();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomEntityReference::QDomEntityReference()
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomEntityReference_initialize_1native__Lio_qt_xml_QDomEntityReference_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntityReference::QDomEntityReference()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntityReference, sizeof(QDomEntityReference), typeid(QDomEntityReference), 0, false, &deleter_QDomEntityReference, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QDomEntityReference(QDomEntityReference)
void __qt_construct_QDomEntityReference_cref_QDomEntityReference(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QDomEntityReference(QDomEntityReference)")
    jobject entityReference0 = __java_arguments[0].l;
    const QDomEntityReference& __qt_entityReference0 = qtjambi_cast<const QDomEntityReference&>(__jni_env, entityReference0);
    QDomEntityReference *__qt_this = new(__qtjambi_ptr) QDomEntityReference(__qt_entityReference0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomEntityReference::QDomEntityReference(QDomEntityReference)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomEntityReference_initialize_1native__Lio_qt_xml_QDomEntityReference_2Lio_qt_xml_QDomEntityReference_2
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject entityReference0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomEntityReference::QDomEntityReference(QDomEntityReference)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = entityReference0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomEntityReference_cref_QDomEntityReference, sizeof(QDomEntityReference), typeid(QDomEntityReference), 0, false, &deleter_QDomEntityReference, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomEntityReference
void __qt_destruct_QDomEntityReference(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomEntityReference")
    reinterpret_cast<QDomEntityReference*>(ptr)->~QDomEntityReference();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomEntityReference::operator=(QDomEntityReference)
extern "C" JNIEXPORT void JNICALL Java_io_qt_xml_QDomEntityReference_assign_1native_1cref_1QDomEntityReference__JJ
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QDomEntityReference *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntityReference>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomEntityReference::operator=(QDomEntityReference)", __this_nativeId)
        const QDomEntityReference& __qt_other0 = QtJambiAPI::valueReferenceFromNativeId<QDomEntityReference>(other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)
// emitting (writeCloneFunction)

extern "C" JNIEXPORT jobject JNICALL Java_io_qt_xml_QDomEntityReference_clone_1native
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomEntityReference *__qt_this = QtJambiAPI::objectFromNativeId<QDomEntityReference>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomEntityReference(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomEntityReference>("QDomEntityReference", "io/qt/xml/QDomEntityReference");
    Q_UNUSED(typeId)
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomEntityReference, {
        ConstructorInfo{&__qt_construct_QDomEntityReference, nullptr}
       ,ConstructorInfo{&__qt_construct_QDomEntityReference_cref_QDomEntityReference, "Lio/qt/xml/QDomEntityReference;"}
    });
    registerDeleter(typeId, &deleter_QDomEntityReference);
    registerMetaType<QDomEntityReference>("QDomEntityReference");
}
